aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/Updates/InstallationInfo.cs
diff options
context:
space:
mode:
authorWWWesten <4700006+WWWesten@users.noreply.github.com>2021-11-01 23:43:29 +0500
committerGitHub <noreply@github.com>2021-11-01 23:43:29 +0500
commit0a14279e2a21bcb9654a06a2d49e1e4f0cc5329c (patch)
treee1b1bd603b011ca98e5793e356326bf4a35a7050 /MediaBrowser.Model/Updates/InstallationInfo.cs
parentf2817fef743eeb75a00782ceea363b2d3e7dc9f2 (diff)
parent76eeb8f655424d295e73ced8349c6fefee6ddb12 (diff)
Merge branch 'jellyfin:master' into master
Diffstat (limited to 'MediaBrowser.Model/Updates/InstallationInfo.cs')
-rw-r--r--MediaBrowser.Model/Updates/InstallationInfo.cs40
1 files changed, 25 insertions, 15 deletions
diff --git a/MediaBrowser.Model/Updates/InstallationInfo.cs b/MediaBrowser.Model/Updates/InstallationInfo.cs
index a3f19e2360..cc600de9de 100644
--- a/MediaBrowser.Model/Updates/InstallationInfo.cs
+++ b/MediaBrowser.Model/Updates/InstallationInfo.cs
@@ -1,16 +1,20 @@
+#nullable disable
+
using System;
+using System.Text.Json.Serialization;
namespace MediaBrowser.Model.Updates
{
/// <summary>
- /// Class InstallationInfo
+ /// Class InstallationInfo.
/// </summary>
public class InstallationInfo
{
/// <summary>
- /// Gets or sets the id.
+ /// Gets or sets the Id.
/// </summary>
- /// <value>The id.</value>
+ /// <value>The Id.</value>
+ [JsonPropertyName("Guid")]
public Guid Id { get; set; }
/// <summary>
@@ -20,27 +24,33 @@ namespace MediaBrowser.Model.Updates
public string Name { get; set; }
/// <summary>
- /// Gets or sets the assembly guid.
+ /// Gets or sets the version.
/// </summary>
- /// <value>The guid of the assembly.</value>
- public string AssemblyGuid { get; set; }
+ /// <value>The version.</value>
+ public Version Version { get; set; }
/// <summary>
/// Gets or sets the version.
/// </summary>
- /// <value>The version.</value>
- public string Version { get; set; }
+ /// <value>The changelog.</value>
+ public string Changelog { get; set; }
+
+ /// <summary>
+ /// Gets or sets the source URL.
+ /// </summary>
+ /// <value>The source URL.</value>
+ public string SourceUrl { get; set; }
/// <summary>
/// Gets or sets the update class.
/// </summary>
- /// <value>The update class.</value>
- public PackageVersionClass UpdateClass { get; set; }
+ /// <value>The checksum.</value>
+ public string Checksum { get; set; }
/// <summary>
- /// Gets or sets the percent complete.
+ /// Gets or sets package information for the installation.
/// </summary>
- /// <value>The percent complete.</value>
- public double? PercentComplete { get; set; }
+ /// <value>The package information.</value>
+ public PackageInfo PackageInfo { get; set; }
}
}
@@ -20,27 +24,33 @@ namespace MediaBrowser.Model.Updates
/// <summary>
- /// Gets or sets the version.
+ /// Gets or sets the changelog for this version.
/// </summary>
@@ -20,27 +24,33 @@ namespace MediaBrowser.Model.Updates
/// <summary>
- /// Gets or sets the update class.
+ /// Gets or sets a checksum for the binary.
/// </summary>